==> nextcloud-30.0.5.tgz: nextcloud/apps/viewer/l10n/de.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Betrachter",
    "Simple file viewer with slideshow for media" : "Einfacher Datei-Betrachter mit Diashow für Medien ",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Zeige deine letzten Urlaubsfotos und -videos wie im Film, gib einen Einblick in deinen neuesten Roman direkt aus deiner Nextcloud, wähle die besten GIF-Dateien aus deiner Sammlung dank der direkten Voransicht deiner favorisierten Dateien und viel mehr!",
    "Your browser does not support audio." : "Dein Browser unterstützt kein Audio.",
    "Error loading {name}" : "Fehler beim Laden von {name}",
    "Image saved" : "Bild gespeichert",
    "Error saving image" : "Fehler beim Speichern des Bildes",
    "Unsaved changes" : "Ungespeicherte Änderungen",
    "Drop changes" : "Änderungen löschen",
    "Play the live photo" : "Live-Foto abspielen",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "Dein Browser unterstützt keine Videos.",
    "Edit" : "Bearbeiten",
    "Exit full screen" : "Vollbild verlassen",
    "Full screen" : "Vollbild",
    "Open sidebar" : "Seitenleiste öffnen",
    "Download" : "Herunterladen",
    "Delete" : "Löschen",
    "This file no longer exists" : "Diese Datei existiert nicht mehr.",
    "There is no plugin available to display this file type" : "Es ist kein Plugin zum Anzeigen dieses Dateityps verfügbar",
    "View" : "Ansicht",
    "Name" : "Name",
    "Save" : "Speichern",
    "Save as" : "Speichern als",
    "Back" : "Zurück",
    "Loading …" : "Lade …",
    "Reset" : "Zurücksetzen",
    "All changes will be lost." : "Alle Änderungen gehen verloren.",
    "Are you sure you want to continue?" : "Bist du dir sicher, dass du fortsetzen möchtest?",
    "Cancel" : "Abbrechen",
    "Apply" : "Anwenden",
    "Warning" : "Warnung",
    "Confirm" : "Bestätigen",
    "Discard changes" : "Änderungen verwerfen",
    "Undo" : "Rückgängig",
    "Redo" : "Wiederherstellen",
    "Show original image" : "Originalbild anzeigen",
    "Zoom in" : "Hinein zoomen",
    "Zoom out" : "Hinauszoomen",
    "Toggle zoom menu" : "Zoom-Menü umschalten",
    "Adjust" : "Anpassen",
    "Fine-tune" : "Feinabstimmung",
    "Filters" : "Filter",
    "Watermark" : "Wasserzeichen",
    "Draw" : "Zeichnen",
    "Resize" : "Größe ändern",
    "Image name" : "BIldname",
    "Invalid image." : "Ungültiges Bild",
    "Error while uploading the image." : "Fehler beim Hochladen des Bildes.",
    "are not images" : "Sind keine Bilder",
    "is not an image" : "Ist kein Bild",
    "to be uploaded" : "zum Hochladen",
    "Crop" : "Zuschneiden",
    "Original" : "Original",
    "Custom" : "Benutzerdefiniert",
    "Square" : "Quadrat",
    "Landscape" : "Landschaft",
    "Portrait" : "Porträt",
    "Ellipse" : "Ellipse",
    "Classic TV" : "Klassisches Fernsehen",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Pfeil",
    "Blur" : "Verwischen",
    "Brightness" : "Helligkeit",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Spiegeln X rückgängig",
    "Flip X" : "Spiegeln X",
    "Un-flip Y" : "Spiegeln Y rückgängig",
    "Flip Y" : "Spiegeln Y",
    "HSV" : "HSV",
    "Hue" : "Farbton",
    "Saturation" : "Sättigung",
    "Value" : "Wert",
    "Image" : "Bild",
    "Importing …" : "Importiere …",
    "+ Add image" : "+ Bild hinzufügen",
    "Upload image" : "Bild hochladen",
    "From gallery" : "Von der Galerie",
    "Line" : "Linie",
    "Pen" : "Stift",
    "Polygon" : "Polygon",
    "Sides" : "Seiten",
    "Rectangle" : "Rechteck",
    "Corner Radius" : "Eckenradius",
    "Width in pixels" : "Breite in Pixel",
    "Height in pixels" : "Höhe in Pixel",
    "Toggle ratio lock" : "Verhältnis-Sperre umschalten",
    "Reset to original image size" : "Auf ursprüngliche Bildgröße zurücksetzen",
    "Rotate" : "Rotieren",
    "Text" : "Text",
    "Text spacing" : "Textabstand",
    "Text alignment" : "Textausrichtung",
    "Font family" : "Schriftenfamilie",
    "Size" : "Größe",
    "Letter spacing" : "Buchstaben-Abstand",
    "Line height" : "Zeilenhöhe",
    "Warmth" : "Wärme",
    "+ Add watermark" : "+ Wasserzeichen hinzufügen",
    "+ Add text watermark" : "+ Text-Wasserzeichen hinzufügen",
    "Choose watermark type" : "Typ des Wasserzeichens auswählen",
    "Upload watermark" : "Wasserzeichenhochladen",
    "Add as text" : "AlsTexthinzufügen",
    "Padding" : "Auffüllen",
    "Paddings" : "Auffüllungen",
    "Shadow" : "Schatten",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertikal",
    "Opacity" : "Deckkraft",
    "Transparency" : "Transparenz",
    "Position" : "Position",
    "Stroke" : "Strich",
    "Save image as" : "Bild speichern unter",
    "Extension" : "Erweiterung",
    "Format" : "Format",
    "Name is required." : "Name ist erforderlich.",
    "Quality" : "Qualität",
    "Saved image size (width x height)" : "Gespeicherte Bildgröße (Breite x Höhe)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Beachte, dass der ausgewählte Zuschneidebereich kleiner ist als die angewendete Größenänderung, was zu Qualitätseinbußen führen kann.",
    "Actual size (100%)" : "Tatsächliche Größe (100%)",
    "Fit size" : "Größe anpassen",
    "Select image to add …" : "Bild zum Hinzufügen auswählen …",
    "Failed to load image." : "Fehler beim Laden des Bildes.",
    "Menu" : "Menü",
    "Width" : "Breite",
    "Height" : "Größe",
    "No preview available for this crop item" : "Für diesen Zuschnitt ist keine Vorschau verfügbar"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.11.tgz: nextcloud/apps/viewer/l10n/de.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Betrachter",
    "Simple file viewer with slideshow for media" : "Einfacher Datei-Betrachter mit Diashow für Medien ",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Zeige deine letzten Urlaubsfotos und -videos wie im Film, gib einen Einblick in deinen neuesten Roman direkt aus deiner Nextcloud, wähle die besten GIF-Dateien aus deiner Sammlung dank der direkten Voransicht deiner favorisierten Dateien und viel mehr!",
    "Your browser does not support audio." : "Dein Browser unterstützt kein Audio.",
    "Error loading {name}" : "Fehler beim Laden von {name}",
    "Image saved" : "Bild gespeichert",
    "Error saving image" : "Fehler beim Speichern des Bildes",
    "Unsaved changes" : "Ungespeicherte Änderungen",
    "Drop changes" : "Änderungen löschen",
    "Play the live photo" : "Live-Foto abspielen",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "Dein Browser unterstützt keine Videos.",
    "This file no longer exists" : "Diese Datei existiert nicht mehr.",
    "There is no plugin available to display this file type" : "Es ist kein Plugin zum Anzeigen dieses Dateityps verfügbar",
    "Edit" : "Bearbeiten",
    "Exit full screen" : "Vollbild verlassen",
    "Full screen" : "Vollbild",
    "Open sidebar" : "Seitenleiste öffnen",
    "Download" : "Herunterladen",
    "Delete" : "Löschen",
    "View" : "Ansicht",
    "Name" : "Name",
    "Save" : "Speichern",
    "Save as" : "Speichern als",
    "Back" : "Zurück",
    "Loading …" : "Lade …",
    "Reset" : "Zurücksetzen",
    "All changes will be lost." : "Alle Änderungen gehen verloren.",
    "Are you sure you want to continue?" : "Bist du dir sicher, dass du fortsetzen möchtest?",
    "Cancel" : "Abbrechen",
    "Apply" : "Anwenden",
    "Warning" : "Warnung",
    "Confirm" : "Bestätigen",
    "Discard changes" : "Änderungen verwerfen",
    "Undo" : "Rückgängig",
    "Redo" : "Wiederherstellen",
    "Show original image" : "Originalbild anzeigen",
    "Zoom in" : "Hinein zoomen",
    "Zoom out" : "Hinauszoomen",
    "Toggle zoom menu" : "Zoom-Menü umschalten",
    "Adjust" : "Anpassen",
    "Fine-tune" : "Feinabstimmung",
    "Filters" : "Filter",
    "Watermark" : "Wasserzeichen",
    "Draw" : "Zeichnen",
    "Resize" : "Größe ändern",
    "Image name" : "BIldname",
    "Invalid image." : "Ungültiges Bild",
    "Error while uploading the image." : "Fehler beim Hochladen des Bildes.",
    "are not images" : "Sind keine Bilder",
    "is not an image" : "Ist kein Bild",
    "to be uploaded" : "zum Hochladen",
    "Crop" : "Zuschneiden",
    "Original" : "Original",
    "Custom" : "Benutzerdefiniert",
    "Square" : "Quadrat",
    "Landscape" : "Landschaft",
    "Portrait" : "Porträt",
    "Ellipse" : "Ellipse",
    "Classic TV" : "Klassisches Fernsehen",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Pfeil",
    "Blur" : "Verwischen",
    "Brightness" : "Helligkeit",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Spiegeln X rückgängig",
    "Flip X" : "Spiegeln X",
    "Un-flip Y" : "Spiegeln Y rückgängig",
    "Flip Y" : "Spiegeln Y",
    "HSV" : "HSV",
    "Hue" : "Farbton",
    "Saturation" : "Sättigung",
    "Value" : "Wert",
    "Image" : "Bild",
    "Importing …" : "Importiere …",
    "+ Add image" : "+ Bild hinzufügen",
    "Upload image" : "Bild hochladen",
    "From gallery" : "Von der Galerie",
    "Line" : "Linie",
    "Pen" : "Stift",
    "Polygon" : "Polygon",
    "Sides" : "Seiten",
    "Rectangle" : "Rechteck",
    "Corner Radius" : "Eckenradius",
    "Width in pixels" : "Breite in Pixel",
    "Height in pixels" : "Höhe in Pixel",
    "Toggle ratio lock" : "Verhältnis-Sperre umschalten",
    "Reset to original image size" : "Auf ursprüngliche Bildgröße zurücksetzen",
    "Rotate" : "Rotieren",
    "Text" : "Text",
    "Text spacing" : "Textabstand",
    "Text alignment" : "Textausrichtung",
    "Font family" : "Schriftenfamilie",
    "Size" : "Größe",
    "Letter spacing" : "Buchstaben-Abstand",
    "Line height" : "Zeilenhöhe",
    "Warmth" : "Wärme",
    "+ Add watermark" : "+ Wasserzeichen hinzufügen",
    "+ Add text watermark" : "+ Text-Wasserzeichen hinzufügen",
    "Choose watermark type" : "Typ des Wasserzeichens auswählen",
    "Upload watermark" : "Wasserzeichenhochladen",
    "Add as text" : "AlsTexthinzufügen",
    "Padding" : "Auffüllen",
    "Paddings" : "Auffüllungen",
    "Shadow" : "Schatten",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertikal",
    "Opacity" : "Deckkraft",
    "Transparency" : "Transparenz",
    "Position" : "Position",
    "Stroke" : "Strich",
    "Save image as" : "Bild speichern unter",
    "Extension" : "Erweiterung",
    "Format" : "Format",
    "Name is required." : "Name ist erforderlich.",
    "Quality" : "Qualität",
    "Saved image size (width x height)" : "Gespeicherte Bildgröße (Breite x Höhe)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Beachte, dass der ausgewählte Zuschneidebereich kleiner ist als die angewendete Größenänderung, was zu Qualitätseinbußen führen kann.",
    "Actual size (100%)" : "Tatsächliche Größe (100%)",
    "Fit size" : "Größe anpassen",
    "Select image to add …" : "Bild zum Hinzufügen auswählen …",
    "Failed to load image." : "Bild konnte nicht geladen werden",
    "Menu" : "Menü",
    "Width" : "Breite",
    "Height" : "Größe",
    "No preview available for this crop item" : "Für diesen Zuschnitt ist keine Vorschau verfügbar"
},
"nplurals=2; plural=(n != 1);");
